//+------------------------------------------------------------------+
//|                                               MTF_Basket_Sem.mq4 |
//|                                                      version 1.1 |
//|                          Copywrong  2010, Splash Software Corp. |
//|                                                               ;) |
//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
//| Description: Dis phile is an MQL4 indicator file.                |
//| Use it for the multitimeframe basket semaphoring. :)             |
//+------------------------------------------------------------------+
#property copyright " 2010, Splash"
#property indicator_chart_window
//+------------------------------------------------------------------+
#define MIN_PAIRS       1
#define MAX_PAIRS       14
#define MAX_INDICATORS  4
#define MAX_TIMEFRAMES  6
//+------------------------------------------------------------------+
//| Input parameters                                                 |
//+------------------------------------------------------------------+
extern int     NumPairs =  8;
extern string  Pair1 =     "GBPUSD";
extern string  Pair2 =     "EURJPY";
extern string  Pair3 =     "AUDUSD";
extern string  Pair4 =     "NZDJPY";
extern string  Pair5 =     "EURUSD";
extern string  Pair6 =     "GBPJPY";
extern string  Pair7 =     "NZDUSD";
extern string  Pair8 =     "AUDJPY";
extern string  Pair9 =     "CHFJPY";
extern string  Pair10 =    "EURCHF";
extern string  Pair11 =    "GBPCHF";
extern string  Pair12 =    "USDJPY";
extern string  Pair13 =    "CADJPY";
extern string  Pair14 =    "EURGBP";
extern int     WPR_per =   14;
extern int     RVI_per =   5;
extern int     RSI_per =   13;
extern int     DTO_k =     8;
extern int     DTO_d =     3;
extern int     DTO_s =     5;
extern int     X =         10;   // X;
extern int     Y =         10;   // Y;
extern int     Size =      25;   // Size;
//+------------------------------------------------------------------+
//| Variables                                                        |
//+------------------------------------------------------------------+
string   Pairs[];                                     // Basket;
int      Semaphores[MAX_INDICATORS][MAX_TIMEFRAMES];  // Semaphoren, the. ;-)
int      TimeFrames[MAX_TIMEFRAMES];
string   TimeFrameNames[MAX_TIMEFRAMES];
string   IndNames[MAX_INDICATORS];
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   int i, j;

   if ((NumPairs < MIN_PAIRS) || (NumPairs > MAX_PAIRS))
    NumPairs = MAX_PAIRS;
   
   IndicatorShortName("MTF_Basket_Sem("+ NumPairs + ")");
   ArrayResize(Pairs, NumPairs);

   switch (NumPairs)
   {
    case 14:   Pairs[13] = Pair14;
    case 13:   Pairs[12] = Pair13;
    case 12:   Pairs[11] = Pair12;
    case 11:   Pairs[10] = Pair11;
    case 10:   Pairs[9] =  Pair10;
    case 9:    Pairs[8] =  Pair9;
    case 8:    Pairs[7] =  Pair8;
    case 7:    Pairs[6] =  Pair7;
    case 6:    Pairs[5] =  Pair6;
    case 5:    Pairs[4] =  Pair5;
    case 4:    Pairs[3] =  Pair4;
    case 3:    Pairs[2] =  Pair3;
    case 2:    Pairs[1] =  Pair2;
    case 1:    Pairs[0] =  Pair1;
   }

   TimeFrames[0] = 10080;
   TimeFrames[1] = 1440;
   TimeFrames[2] = 240;
   TimeFrames[3] = 60;
   TimeFrames[4] = 30;
   TimeFrames[5] = 15;
   
   TimeFrameNames[0] = "W1";
   TimeFrameNames[1] = "D1";
   TimeFrameNames[2] = "H4";
   TimeFrameNames[3] = "H1";
   TimeFrameNames[4] = "M30";
   TimeFrameNames[5] = "M15";

   IndNames[0] = "WPR";
   IndNames[1] = "DTO";
   IndNames[2] = "RSI";
   IndNames[3] = "RVI";

   return (0);
}
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
   clear();
   
   return (0);
}
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
   calculate();
   draw();

   return (0);
}
//+------------------------------------------------------------------+
//| Custom indicator calculation function                            |
//+------------------------------------------------------------------+
void calculate()
{
   int i, j;
   double value1, value2, delta;

   for (i = MAX_TIMEFRAMES - 1; i >= 0; i--)
   {
    value1 = 0.0;
    for (j = 0; j < NumPairs; j++)
     value1 += iWPR(Pairs[j], TimeFrames[i], WPR_per, 0);
    value1 = MathRound(value1 / NumPairs);
    if (value1 <= -80)                    Semaphores[0][i] = 0xDD;
    if ((value1 > -80) && (value1 < -20)) Semaphores[0][i] = 0xF4;
    if (value1 >= -20)                    Semaphores[0][i] = 0xDE;

    value1 = 0.0;
    value2 = 0.0;
    for (j = 0; j < NumPairs; j++)
    {
     value1 += iCustom(Pairs[j], TimeFrames[i], "DTOsc", RSI_per, DTO_k, DTO_s, DTO_d, true, 0, 0);
     value2 += iCustom(Pairs[j], TimeFrames[i], "DTOsc", RSI_per, DTO_k, DTO_s, DTO_d, true, 1, 0);
    }
    delta = MathRound((value1 / NumPairs) - (value2 / NumPairs));
    value1 = MathRound(value1 / NumPairs);
    if ((value1 < 50) && (delta > 0))                                         Semaphores[1][i] = 0xDD;
    if (((value1 >= 50) && (delta > 0)) || ((value1 <= 50) && (delta < 0)))   Semaphores[1][i] = 0xF4;
    if ((value1 > 50) && (delta < 0))                                         Semaphores[1][i] = 0xDE;

    value1 = 0.0;
    value2 = 0.0;
    for (j = 0; j < NumPairs; j++)
    {
     value1 += iRSI(Pairs[j], TimeFrames[i], RSI_per, PRICE_CLOSE, 0);
     value2 += iRSI(Pairs[j], TimeFrames[i], RSI_per, PRICE_CLOSE, 1);
    }
    delta = ((value1 / NumPairs) - (value2 / NumPairs)) * 10;
    value1 = MathRound(value1 / NumPairs);
    if ((value1 <= 35) || (delta > 0)) Semaphores[2][i] = 0xDD;
    if ((value1 >= 65) || (delta < 0)) Semaphores[2][i] = 0xDE;

    value1 = 0.0;
    value2 = 0.0;
    for (j = 0; j < NumPairs; j++)
    {
     value1 += iRVI(Pairs[j], TimeFrames[i], RVI_per, 0, 0);
     value2 += iRVI(Pairs[j], TimeFrames[i], RVI_per, 1, 0);
    }
    delta = ((value1 / NumPairs) - (value2 / NumPairs)) * 1000;
    if (delta > 0)   Semaphores[3][i] = 0xDD;
    if (delta <= 0)  Semaphores[3][i] = 0xDE;
   }
}
//+------------------------------------------------------------------+
//| Custom indicator draw function                                   |
//+------------------------------------------------------------------+
void draw()
{
   int i, j;
   color cl;

   for (i = 0; i < MAX_INDICATORS; i++)
    draw_label("mbs_lbl_ind_" + i, X, Y + (4*Size/3) + (i * 4*Size/3), IndNames[i], Size/2, "Calibri Bold", Silver);
   for (i = 0; i < MAX_TIMEFRAMES; i++)
    draw_label("mbs_lbl_tf_" + i, X + (5*Size/3) + (i * 5*Size/3), Y, TimeFrameNames[i], Size/2, "Calibri Bold", Silver);

   for (i = 0; i < MAX_INDICATORS; i++)
   {
    for (j = 0; j < MAX_TIMEFRAMES; j++)
    {
     switch (Semaphores[i][j])
     {
      case 0xDD:   { cl = Lime;   break; }
      case 0xDE:   { cl = Red;    break; }
      case 0xF4:   { cl = Yellow; break; }
      default:     { cl = Black;  break; }
     }
     draw_label("mbs_lbl_sem_" + i + j, X + (5*Size/3) + (j * 5*Size/3), Y + (1*Size/1) + (i * 4*Size/3), CharToStr(Semaphores[i][j]), Size, "Wingdings", cl);
    }
   }
}
//+------------------------------------------------------------------+
//| Custom indicator clear function                                  |
//+------------------------------------------------------------------+
void clear()
{
   int i, j;

   for (i = 0; i < MAX_INDICATORS; i++)
    clear_label("mbs_lbl_ind_" + i);
   for (i = 0; i < MAX_TIMEFRAMES; i++)
    clear_label("mbs_lbl_tf_" + i);
   for (i = 0; i < MAX_INDICATORS; i++)
   {
    for (j = 0; j < MAX_TIMEFRAMES; j++)
     clear_label("mbs_lbl_sem_" + i + j);
   }
}
//+------------------------------------------------------------------+
//| Draw label function                                              |
//+------------------------------------------------------------------+
void draw_label(string name, int dist_x, int dist_y, string text, int font_size, string font_name, color text_color)
{
   if (ObjectFind(name) == -1)
    ObjectCreate(name, OBJ_LABEL, 0, 0, 0);
   ObjectSet(name, OBJPROP_XDISTANCE, dist_x);
   ObjectSet(name, OBJPROP_YDISTANCE, dist_y);
   ObjectSetText(name, text, font_size, font_name, text_color);
}
//+------------------------------------------------------------------+
//| Clear label function                                             |
//+------------------------------------------------------------------+
void clear_label(string name)
{
   if (ObjectFind(name) != -1)
    ObjectDelete(name);
}
//+------------------------------------------------------------------+
//| EOF :)                                                           |
//+------------------------------------------------------------------+

